@@ -137,7 +137,7 @@ struct Dictionary_s
 
 	/* Affixes are used during the tokenization stage. */
 	Dictionary      affix_table;
-	Afdict_class afdict_class;
+	Afdict_class *  afdict_class;
 
 	/* If not null, then use spelling guesser for unknown words */
 	void *          spell_checker; /* spell checker handle */
