@@ -30,29 +30,30 @@ void patch_subscript(char *);
 /* Connector names for the affix class lists in the affix file */
 
 typedef enum {
-	AFDICT_RPUNC=0,
+	AFDICT_RPUNC=1,
 	AFDICT_LPUNC,
-	AFDICT_QUOTES,
 	AFDICT_UNITS,
 	AFDICT_SUF,
 	AFDICT_PRE,
 	AFDICT_MPRE,
+	AFDICT_QUOTES,
+	AFDICT_BULLETS,
 	AFDICT_SANEMORPHISM,
 	AFDICT_END /* must be last */
 } afdict_classnum;
 
 #define AFDICT_CLASSNAMES \
+	"invalid classname", \
 	"RPUNC", \
 	"LPUNC", \
-	"QUOTES", \
 	"UNITS", \
 	"SUF",          /* SUF is used in the Russian dict */ \
 	"PRE",          /* PRE is not used anywhere, yet... */ \
 	"MPRE",         /* Multi-prefix, currently for Hebrew */ \
+	"QUOTES", \
+	"BULLETS", \
 	"SANEMORPHISM"  /* Regexp for sane_morphism() */
 
 #define AFCLASS(afdict, class) (&afdict->afdict_class[class])
 
-#define AFFIX_COUNT_MEM_INCREMENT 64
-
 #endif /* _LG_DICT_COMMON_H_ */
