@@ -47,10 +47,10 @@ typedef struct power_table_s power_table;
 struct power_table_s
 {
 	unsigned int power_table_size;
-	unsigned int l_table_size[MAX_SENTENCE];  /* the sizes of the hash tables */
-	unsigned int r_table_size[MAX_SENTENCE];
-	C_list ** l_table[MAX_SENTENCE];
-	C_list ** r_table[MAX_SENTENCE];
+	unsigned int *l_table_size;  /* the sizes of the hash tables */
+	unsigned int *r_table_size;
+	C_list *** l_table;
+	C_list *** r_table;
 };
 
 typedef struct cms_struct Cms;
@@ -833,7 +833,7 @@ static Exp* purge_Exp(Exp *e)
 /**
  * Returns TRUE if c can match anything in the set S.
  */
-static inline int matches_S(connector_table *ct, Connector * c, int dir)
+static inline bool matches_S(connector_table *ct, Connector * c, char dir)
 {
 	Connector * e;
 	unsigned int h = hash_S(c);
@@ -861,7 +861,7 @@ static inline int matches_S(connector_table *ct, Connector * c, int dir)
  * in e that are not matched by anything in the current set.
  * Returns the number of connectors so marked.
  */
-static int mark_dead_connectors(connector_table *ct, Exp * e, int dir)
+static int mark_dead_connectors(connector_table *ct, Exp * e, char dir)
 {
 	int count;
 	count = 0;
@@ -956,7 +956,7 @@ void expression_prune(Sentence sent)
 {
 	int N_deleted;
 	X_node * x;
-	int w;
+	size_t w;
 	Connector *ct[CONTABSZ];
 	Connector *dummy_list = NULL;
 
@@ -1007,7 +1007,7 @@ DBG(printf("after purging: "); print_expression(x->exp); printf("\n"););
 
 		/* Right-to-left pass */
 		N_deleted = 0;
-		for (w = sent->length-1; w >= 0; w--)
+		for (w = sent->length-1; w != (size_t) -1; w--)
 		{
 			for (x = sent->word[w].x; x != NULL; x = x->next)
 			{
@@ -1149,6 +1149,8 @@ static void power_table_delete(power_table *pt)
 		}
 		xfree((char *)pt->r_table[w], pt->r_table_size[w] * sizeof (C_list *));
 	}
+	xfree(pt->l_table_size, 2 * pt->power_table_size * sizeof(unsigned int));
+	xfree(pt->l_table, 2 * pt->power_table_size * sizeof(C_list **));
 	xfree(pt, sizeof(power_table));
 }
 
@@ -1168,10 +1170,10 @@ static void put_into_power_table(unsigned int size, C_list ** t, Connector * c,
 	m->shallow = shal;
 }
 
-static int set_dist_fields(Connector * c, int w, int delta)
+static int set_dist_fields(Connector * c, size_t w, int delta)
 {
 	int i;
-	if (c==NULL) return w;
+	if (c == NULL) return (int) w;
 	i = set_dist_fields(c->next, w, delta) + delta;
 	c->word = i;
 	return i;
@@ -1183,7 +1185,7 @@ static int set_dist_fields(Connector * c, int w, int delta)
 static power_table * power_table_new(Sentence sent)
 {
 	power_table *pt;
-	int w, len;
+	size_t w, len;
 	unsigned int i, size;
 	C_list ** t;
 	Disjunct * d, * xd, * head;
@@ -1191,6 +1193,10 @@ static power_table * power_table_new(Sentence sent)
 
 	pt = (power_table *) xalloc (sizeof(power_table));
 	pt->power_table_size = sent->length;
+	pt->l_table_size = xalloc (2 * sent->length * sizeof(unsigned int));
+	pt->r_table_size = pt->l_table_size + sent->length;
+	pt->l_table = xalloc (2 * sent->length * sizeof(C_list **));
+	pt->r_table = pt->l_table + sent->length;
 
    /* First, we initialize the word fields of the connectors, and
 	  eliminate those disjuncts with illegal connectors */
@@ -1200,7 +1206,7 @@ static power_table * power_table_new(Sentence sent)
 	  for (d=sent->word[w].d; d!=NULL; d=xd) {
 		  xd = d->next;
 		  if ((set_dist_fields(d->left, w, -1) < 0) ||
-			  (set_dist_fields(d->right, w, 1) >= sent->length)) {
+			  (set_dist_fields(d->right, w, 1) >= (int) sent->length)) {
 			  d->next = NULL;
 			  free_disjuncts(d);
 		  } else {
@@ -1461,12 +1467,12 @@ left_connector_list_update(prune_context *pc, Connector *c,
  * N_words - 1.   If it does find a way to match it, it updates the
  * c->word fields correctly.
  */
-static int
+static size_t
 right_connector_list_update(prune_context *pc, Sentence sent, Connector *c,
-                            int word_c, int w, Boolean shallow)
+                            size_t word_c, size_t w, bool shallow)
 {
-	int n;
-	int foundmatch;
+	size_t n;
+	bool foundmatch;
 
 	if (c == NULL) return w;
 	n = right_connector_list_update(pc, sent, c->next, word_c, w, FALSE) + 1;
@@ -1495,7 +1501,7 @@ int power_prune(Sentence sent, int mode, Parse_Options opts)
 	prune_context *pc;
 	Disjunct *d, *free_later, *dx, *nd;
 	Connector *c;
-	int w, N_deleted, total_deleted;
+	size_t w, N_deleted, total_deleted;
 
 	pc = (prune_context *) xalloc (sizeof(prune_context));
 	pc->power_cost = 0;
@@ -1548,7 +1554,7 @@ int power_prune(Sentence sent, int mode, Parse_Options opts)
 			sent->word[w].d = nd;
 		}
 		if (verbosity > 2) {
-			printf("l->r pass changed %d and deleted %d\n",pc->N_changed,N_deleted);
+			printf("l->r pass changed %d and deleted %zu\n", pc->N_changed, N_deleted);
 		}
 
 		if (pc->N_changed == 0) break;
@@ -1556,7 +1562,7 @@ int power_prune(Sentence sent, int mode, Parse_Options opts)
 		pc->N_changed = N_deleted = 0;
 		/* right-to-left pass */
 
-		for (w = sent->length-1; w >= 0; w--) {
+		for (w = sent->length-1; w != (size_t) -1; w--) {
 			if ((2 == w%7) && parse_options_resources_exhausted(opts)) break;
 			for (d = sent->word[w].d; d != NULL; d = d->next) {
 				if (d->right == NULL) continue;
@@ -1583,7 +1589,7 @@ int power_prune(Sentence sent, int mode, Parse_Options opts)
 		}
 
 		if (verbosity > 2) {
-			printf("r->l pass changed %d and deleted %d\n", pc->N_changed,N_deleted);
+			printf("r->l pass changed %d and deleted %zu\n", pc->N_changed, N_deleted);
 		}
 
 		if (pc->N_changed == 0) break;
@@ -1847,7 +1853,8 @@ static int pp_prune(Sentence sent, Parse_Options opts)
 	pp_rule rule;
 	const char * selector;
 	pp_linkset * link_set;
-	int i, w, dir;
+	size_t i, w;
+	char dir;
 	Disjunct *d;
 	Connector *c;
 	int change, total_deleted, N_deleted, deleteme;
