@@ -4,8 +4,7 @@
 /* All rights reserved                                                   */
 /*                                                                       */
 /* Use of the link grammar parsing system is subject to the terms of the */
-/* license set forth in the LICENSE file included with this software,    */
-/* and also available at http://www.link.cs.cmu.edu/link/license.html    */
+/* license set forth in the LICENSE file included with this software.    */
 /* This license allows free redistribution and use in source and binary  */
 /* forms, with or without modification, subject to certain conditions.   */
 /*                                                                       */
@@ -36,8 +35,9 @@ int getrusage(int who, struct rusage *rusage);
 /* Declaration missing from sys/resource.h in sun operating systems (?) */
 #endif /* __sun__ */
 
-#include "api.h"
+#include "api-structures.h"
 #include "resources.h"
+#include "utilities.h"
 
 #define MAX_PARSE_TIME_UNLIMITED -1
 #define MAX_MEMORY_UNLIMITED ((size_t) -1)
@@ -162,9 +162,8 @@ static void resources_print_total_space(int verbosity, Resources r)
 		printf("++++");
 		left_print_string(stdout, "Total space",
 		                  "                                            ");
-		printf("%lu bytes (%lu max)\n", 
-			(long unsigned int) get_space_in_use(), 
-			(long unsigned int) get_max_space_used());
+		printf("%zu bytes (%zu max)\n", 
+			get_space_in_use(), get_max_space_used());
 	}
 }
 
