@@ -4,6 +4,13 @@
 #include "Solver.h"
 #include "util.hpp"
 
+extern "C" {
+
+#include "api-structures.h"
+#include "structures.h"
+
+};
+
 // This class represents different guding strategies of LinkParser SAT search
 class Guiding {
 public:
@@ -83,7 +90,7 @@ public:
 
   /* Pass SAT search parameters to the MiniSAT solver */
   void passParametersToSolver(Solver* solver) {
-    for (int v = 0; v < _parameters.size(); v++) {
+    for (size_t v = 0; v < _parameters.size(); v++) {
       solver->setDecisionVar(v, _parameters[v].isDecision);
       if (_parameters[v].isDecision) {
         solver->setActivity(v, _parameters[v].priority);
@@ -95,7 +102,7 @@ public:
 
 protected:
   /* Set the parameters for the given variable to given values */
-  void setParameters(int var, bool isDecision, double priority, double polarity) {
+  void setParameters(size_t var, bool isDecision, double priority, double polarity) {
     if (var >= _parameters.size())
       _parameters.resize(var + 1);
     _parameters[var].isDecision = isDecision;
@@ -159,7 +166,8 @@ public:
   }
 #endif /* USE_FAT_LINKAGES */
 
-  void setThinLinkParameters(int var, int i, int j) {
+  void setThinLinkParameters(int var, int i, int j)
+  {
     bool isDecision = true;
 
     double priority = (double)(j - i);
@@ -169,11 +177,11 @@ public:
 #endif /* USE_FAT_LINKAGES */
 
     double polarity = j - i == 1 ? 1.0 : 0.0;
-    if (i == 0 && j == _sent->length - 2 &&
+    if (i == 0 && j == (int) _sent->length - 2 &&
        isEndingInterpunction(_sent->word[j].alternatives[0])) {
       polarity = 1.0;
     }
-    if (i == 0 && j == _sent->length - 1 &&
+    if (i == 0 && j == (int) _sent->length - 1 &&
       !isEndingInterpunction(_sent->word[j - 1].alternatives[0])) {
       polarity = 1.0;
     }
