@@ -20,9 +20,12 @@ using std::endl;
 
 
 extern "C" {
-#include <link-grammar/api.h>
+#include "analyze-linkage.h"
+#include "and.h"
+#include "extract-links.h"
+#include "post-process.h"
 #include "preparation.h"
-#include "read-dict.h"
+#include "dict-file/read-dict.h"
 }
 
 // Macro DEBUG_print is used to dump to stdout information while debugging
@@ -243,8 +246,9 @@ void SATEncoder::encode() {
 /*-------------------------------------------------------------------------*
  *                         W O R D - T A G S                               *
  *-------------------------------------------------------------------------*/
-void SATEncoder::build_word_tags() {
-  for (int w = 0; w < _sent->length; w++) {
+void SATEncoder::build_word_tags()
+{
+  for (size_t w = 0; w < _sent->length; w++) {
     _word_tags.push_back(WordTag(w, _variables, _sent, _opts));
     int dfs_position = 0;
 
@@ -263,7 +267,7 @@ void SATEncoder::build_word_tags() {
 #endif
 
     char name[MAX_VARIABLE_NAME];
-    sprintf(name, "w%d", w);
+    sprintf(name, "w%zu", w);
     bool leading_right = true;
     bool leading_left = true;
     std::vector<int> eps_right, eps_left;
@@ -274,8 +278,8 @@ void SATEncoder::build_word_tags() {
       free_alternatives(exp);
   }
 
-  for (int wl = 0; wl < _sent->length - 1; wl++) {
-    for (int wr = wl + 1; wr < _sent->length; wr++) {
+  for (size_t wl = 0; wl < _sent->length - 1; wl++) {
+    for (size_t wr = wl + 1; wr < _sent->length; wr++) {
       _word_tags[wl].add_matches_with_word(_word_tags[wr]);
     }
   }
@@ -308,8 +312,9 @@ bool SATEncoder::matches_in_interval(int wi, int pi, int l, int r) {
  *                     S A T I S F A C T I O N                             *
  *-------------------------------------------------------------------------*/
 
-void SATEncoder::generate_satisfaction_conditions() {
-  for (int w = 0; w < _sent->length; w++) {
+void SATEncoder::generate_satisfaction_conditions()
+{
+  for (size_t w = 0; w < _sent->length; w++) {
     if (_sent->word[w].x == NULL) {
       DEBUG_print("Word: " << _sent->word[w].string << " : " << "(null)" << endl);
       handle_null_expression(w);
@@ -326,7 +331,7 @@ void SATEncoder::generate_satisfaction_conditions() {
 #endif
 
     char name[MAX_VARIABLE_NAME];
-    sprintf(name, "w%d", w);
+    sprintf(name, "w%zu", w);
 
     determine_satisfaction(w, name);
     int dfs_position = 0;
@@ -369,7 +374,7 @@ void SATEncoder::generate_satisfaction_for_expression(int w, int& dfs_position,
         char new_var[MAX_VARIABLE_NAME];
         char* last_new_var = new_var;
         char* last_var = var;
-        while(*last_new_var = *last_var) {
+        while((*last_new_var = *last_var)) {
           last_new_var++;
           last_var++;
         }
@@ -417,7 +422,7 @@ void SATEncoder::generate_satisfaction_for_expression(int w, int& dfs_position,
         char new_var[MAX_VARIABLE_NAME];
         char* last_new_var = new_var;
         char* last_var = var;
-        while(*last_new_var = *last_var) {
+        while ((*last_new_var = *last_var)) {
           last_new_var++;
           last_var++;
         }
@@ -823,7 +828,7 @@ void SATEncoder::dfs(int node, const MatrixUpperTriangle<int>& graph, int compon
     return;
 
   components[node] = component;
-  for (int other_node = node + 1; other_node < components.size(); other_node++) {
+  for (size_t other_node = node + 1; other_node < components.size(); other_node++) {
     if (graph(node, other_node))
       dfs(other_node, graph, component, components);
   }
@@ -856,10 +861,10 @@ bool SATEncoder::connectivity_components(std::vector<int>& components) {
   // determine the connectivity components
   components.resize(_sent->length);
   std::fill(components.begin(), components.end(), -1);
-  for (int node = 0; node < _sent->length; node++)
+  for (size_t node = 0; node < _sent->length; node++)
     dfs(node, graph, node, components);
   bool connected = true;
-  for (int node = 0; node < _sent->length; node++) {
+  for (size_t node = 0; node < _sent->length; node++) {
     if (components[node] != 0) {
       connected = false;
     }
@@ -897,14 +902,15 @@ void SATEncoder::generate_disconnectivity_prohibiting(std::vector<int> component
 /*--------------------------------------------------------------------------*
  *                           P L A N A R I T Y                              *
  *--------------------------------------------------------------------------*/
-void SATEncoder::generate_planarity_conditions() {
+void SATEncoder::generate_planarity_conditions()
+{
   vec<Lit> clause;
-  for (int wi1 = 0; wi1 < _sent->length; wi1++) {
-    for (int wj1 = wi1+1; wj1 < _sent->length; wj1++) {
-      for (int wi2 = wj1+1; wi2 < _sent->length; wi2++) {
+  for (size_t wi1 = 0; wi1 < _sent->length; wi1++) {
+    for (size_t wj1 = wi1+1; wj1 < _sent->length; wj1++) {
+      for (size_t wi2 = wj1+1; wi2 < _sent->length; wi2++) {
         if (!_linked_possible(wi1, wi2))
           continue;
-        for (int wj2 = wi2+1; wj2 < _sent->length; wj2++) {
+        for (size_t wj2 = wi2+1; wj2 < _sent->length; wj2++) {
           if (!_linked_possible(wj1, wj2))
             continue;
           clause.growTo(2);
@@ -923,8 +929,9 @@ void SATEncoder::generate_planarity_conditions() {
  *               P O W E R     P R U N I N G                                *
  *--------------------------------------------------------------------------*/
 
-void SATEncoder::generate_epsilon_definitions() {
-  for (int w = 0; w < _sent->length; w++) {
+void SATEncoder::generate_epsilon_definitions()
+{
+  for (size_t w = 0; w < _sent->length; w++) {
     if (_sent->word[w].x == NULL) {
       continue;
     }
@@ -933,7 +940,7 @@ void SATEncoder::generate_epsilon_definitions() {
     Exp* exp = join ? join_alternatives(w) : _sent->word[w].x->exp;
 
     char name[MAX_VARIABLE_NAME];
-    sprintf(name, "w%d", w);
+    sprintf(name, "w%zu", w);
 
     int dfs_position;
 
@@ -949,8 +956,8 @@ void SATEncoder::generate_epsilon_definitions() {
 }
 
 bool SATEncoder::generate_epsilon_for_expression(int w, int& dfs_position, Exp* e,
-                                                 char* var, bool root, char dir) {
-  E_list *l;
+                                                 char* var, bool root, char dir)
+{
   if (e->type == CONNECTOR_type) {
     dfs_position++;
     if (var != NULL) {
@@ -982,7 +989,7 @@ bool SATEncoder::generate_epsilon_for_expression(int w, int& dfs_position, Exp*
         char new_var[MAX_VARIABLE_NAME];
         char* last_new_var = new_var;
         char* last_var = var;
-        while(*last_new_var = *last_var) {
+        while ((*last_new_var = *last_var)) {
           last_new_var++;
           last_var++;
         }
@@ -1032,7 +1039,7 @@ bool SATEncoder::generate_epsilon_for_expression(int w, int& dfs_position, Exp*
       char new_var[MAX_VARIABLE_NAME];
       char* last_new_var = new_var;
       char* last_var = var;
-      while(*last_new_var = *last_var) {
+      while ((*last_new_var = *last_var)) {
         last_new_var++;
         last_var++;
       }
@@ -1061,13 +1068,14 @@ bool SATEncoder::generate_epsilon_for_expression(int w, int& dfs_position, Exp*
   return false;
 }
 
-void SATEncoder::power_prune() {
+void SATEncoder::power_prune()
+{
   generate_epsilon_definitions();
 
   // on two non-adjacent words, a pair of connectors can be used only
   // if not [both of them are the deepest].
 
-  for (int wl = 0; wl < _sent->length - 2; wl++) {
+  for (size_t wl = 0; wl < _sent->length - 2; wl++) {
     const std::vector<PositionConnector>& rc = _word_tags[wl].get_right_connectors();
     std::vector<PositionConnector>::const_iterator rci;
     for (rci = rc.begin(); rci != rc.end(); rci++) {
@@ -1171,7 +1179,8 @@ void SATEncoder::power_prune() {
 /*--------------------------------------------------------------------------*
  *        P O S T P R O C E S S I N G   &  P P     P R U N I N G            *
  *--------------------------------------------------------------------------*/
-void SATEncoder::pp_prune() {
+void SATEncoder::pp_prune()
+{
   const std::vector<int>& link_variables = _variables->link_variables();
 
 
@@ -1181,18 +1190,15 @@ void SATEncoder::pp_prune() {
   pp_knowledge * knowledge;
   knowledge = _sent->dict->postprocessor->knowledge;
 
-  for (int i=0; i<knowledge->n_contains_one_rules; i++) {
-    pp_rule rule;
-    const char * selector;
-    pp_linkset * link_set;
-
-    rule = knowledge->contains_one_rules[i];
-    selector = rule.selector;                                /* selector string for this rule */
-    link_set = rule.link_set;                                /* the set of criterion links */
+  for (size_t i=0; i<knowledge->n_contains_one_rules; i++)
+  {
+    pp_rule rule = knowledge->contains_one_rules[i];
+    // const char * selector = rule.selector;         /* selector string for this rule */
+    pp_linkset * link_set = rule.link_set;            /* the set of criterion links */
 
 
     vec<Lit> triggers;
-    for (int i = 0; i < link_variables.size(); i++) {
+    for (size_t i = 0; i < link_variables.size(); i++) {
       const Variables::LinkVar* var = _variables->link_variable(link_variables[i]);
       if (post_process_match(rule.selector, var->label)) {
         triggers.push(Lit(link_variables[i]));
@@ -1203,9 +1209,9 @@ void SATEncoder::pp_prune() {
       continue;
 
     vec<Lit> criterions;
-    for (int j = 0; j < link_variables.size(); j++) {
+    for (size_t j = 0; j < link_variables.size(); j++) {
       pp_linkset_node *p;
-      for (int hashval = 0; hashval < link_set->hash_table_size; hashval++) {
+      for (size_t hashval = 0; hashval < link_set->hash_table_size; hashval++) {
         for (p = link_set->hash_table[hashval]; p!=NULL; p=p->next) {
           const Variables::LinkVar* var = _variables->link_variable(link_variables[j]);
           if (post_process_match(p->str, var->label)) {
@@ -1278,7 +1284,7 @@ Linkage SATEncoder::create_linkage()
      compute_chosen_words. */
   // XXX should not use alternatives[0], need to try all of them!
   // XXX why are we doing a strcpy? Should be using the stringset!
-  for (int i = 0; i < _sent->length; i++) {
+  for (size_t i = 0; i < _sent->length; i++) {
     char *s = (char *) exalloc(strlen(_sent->word[i].alternatives[0])+1);
     strcpy(s, _sent->word[i].alternatives[0]);
     linkage->word[i] = s;
@@ -1361,7 +1367,8 @@ void SATEncoderConjunctionFreeSentences::determine_satisfaction(int w, char* nam
 }
 
 void SATEncoderConjunctionFreeSentences::generate_satisfaction_for_connector(int wi, int pi, const char* Ci,
-                                                                             char dir, bool multi, int cost, char* var) {
+                                                                             char dir, bool multi, int cost, char* var)
+{
   Lit lhs = Lit(_variables->string_cost(var, cost));
 
 #ifdef _DEBUG
@@ -1386,7 +1393,7 @@ void SATEncoderConjunctionFreeSentences::generate_satisfaction_for_connector(int
   }
 
   vec<Lit> _link_cw_;
-  for (int i = 0; i < _w_.size(); i++)
+  for (size_t i = 0; i < _w_.size(); i++)
     _link_cw_.push(Lit(_variables->link_cw(_w_[i], wi, pi, Ci)));
   generate_or_definition(lhs, _link_cw_);
 
@@ -1401,12 +1408,13 @@ void SATEncoderConjunctionFreeSentences::generate_satisfaction_for_connector(int
 #endif
 }
 
-void SATEncoderConjunctionFreeSentences::generate_linked_definitions() {
+void SATEncoderConjunctionFreeSentences::generate_linked_definitions()
+{
   _linked_possible.resize(_sent->length, 1);
 
   DEBUG_print("------- linked definitions");
-  for (int w1 = 0; w1 < _sent->length; w1++) {
-    for (int w2 = w1 + 1; w2 < _sent->length; w2++) {
+  for (size_t w1 = 0; w1 < _sent->length; w1++) {
+    for (size_t w2 = w1 + 1; w2 < _sent->length; w2++) {
       DEBUG_print("---------- ." << w1 << ". ." << w2 << ".");
       Lit lhs = Lit(_variables->linked(w1, w2));
 
@@ -1427,10 +1435,11 @@ void SATEncoderConjunctionFreeSentences::generate_linked_definitions() {
   DEBUG_print("------- end linked definitions");
 }
 
-void SATEncoder::generate_linked_min_max_planarity() {
+void SATEncoder::generate_linked_min_max_planarity()
+{
   DEBUG_print("---- linked_max");
-  for (int w1 = 0; w1 < _sent->length; w1++) {
-    for (int w2 = 0; w2 < _sent->length; w2++) {
+  for (size_t w1 = 0; w1 < _sent->length; w1++) {
+    for (size_t w2 = 0; w2 < _sent->length; w2++) {
       Lit lhs = Lit(_variables->linked_max(w1, w2));
       vec<Lit> rhs;
       if (w2 < _sent->length - 1) {
@@ -1445,8 +1454,8 @@ void SATEncoder::generate_linked_min_max_planarity() {
 
 
   DEBUG_print("---- linked_min");
-  for (int w1 = 0; w1 < _sent->length; w1++) {
-    for (int w2 = 0; w2 < _sent->length; w2++) {
+  for (size_t w1 = 0; w1 < _sent->length; w1++) {
+    for (size_t w2 = 0; w2 < _sent->length; w2++) {
       Lit lhs = Lit(_variables->linked_min(w1, w2));
       vec<Lit> rhs;
       if (w2 > 0) {
@@ -1461,9 +1470,9 @@ void SATEncoder::generate_linked_min_max_planarity() {
 
 
   vec<Lit> clause;
-  for (int wi = 3; wi < _sent->length; wi++) {
-    for (int wj = 1; wj < wi - 1; wj++) {
-      for (int wl = wj + 1; wl < wi; wl++) {
+  for (size_t wi = 3; wi < _sent->length; wi++) {
+    for (size_t wj = 1; wj < wi - 1; wj++) {
+      for (size_t wl = wj + 1; wl < wi; wl++) {
         clause.growTo(3);
         clause[0] = ~Lit(_variables->linked_min(wi, wj));
         clause[1] = ~Lit(_variables->linked_max(wi, wl - 1));
@@ -1475,9 +1484,9 @@ void SATEncoder::generate_linked_min_max_planarity() {
 
   DEBUG_print("------------");
 
-  for (int wi = 0; wi < _sent->length - 1; wi++) {
-    for (int wj = wi + 1; wj < _sent->length - 1; wj++) {
-      for (int wl = wi+1; wl < wj; wl++) {
+  for (size_t wi = 0; wi < _sent->length - 1; wi++) {
+    for (size_t wj = wi + 1; wj < _sent->length - 1; wj++) {
+      for (size_t wl = wi+1; wl < wj; wl++) {
         clause.growTo(3);
         clause[0] = ~Lit(_variables->linked_max(wi, wj));
         clause[1] = ~Lit(_variables->linked_min(wi, wl + 1));
@@ -1489,9 +1498,9 @@ void SATEncoder::generate_linked_min_max_planarity() {
 
   DEBUG_print("------------");
   clause.clear();
-  for (int wi = 1; wi < _sent->length; wi++) {
-    for (int wj = wi + 2; wj < _sent->length - 1; wj++) {
-      for (int wl = wi + 1; wl < wj; wl++) {
+  for (size_t wi = 1; wi < _sent->length; wi++) {
+    for (size_t wj = wi + 2; wj < _sent->length - 1; wj++) {
+      for (size_t wl = wi + 1; wl < wj; wl++) {
         clause.growTo(2);
         clause[0] = ~Lit(_variables->linked_min(wi, wj));
         clause[1] = Lit(_variables->linked_min(wl, wi));
@@ -1519,8 +1528,8 @@ bool SATEncoderConjunctionFreeSentences::extract_links(Parse_info pi)
     if (_solver->model[_variables->linked(var->left_word, var->right_word)] != l_True)
       continue;
 
-    pi->link_array[current_link].l = var->left_word;
-    pi->link_array[current_link].r = var->right_word;
+    pi->link_array[current_link].lw = var->left_word;
+    pi->link_array[current_link].rw = var->right_word;
     //    pi->link_array[j].name = var->label;
 
     Connector* connector;
