@@ -62,13 +62,6 @@
     current linkage.  It is used to compute the cost of the linkage, and
     also by compute_chosen_words() to compute the chosen_words[].
 
- chosen_words[]
-    An array of pointers to strings.  These are the words to be displayed
-    when printing the solution, the links, etc.  Computed as a function of
-    chosen_disjuncts[] by compute_chosen_words().  This differs from
-    sentence[].string because it contains the suffixes.  It differs from
-    chosen_disjunct[].string in that the idiom symbols have been removed.
-
 #ifdef USE_FAT_LINKAGES
  has_fat_down[]
     An array of chars, one for each word.  TRUE if there is a fat link
@@ -173,7 +166,7 @@ struct Connector_struct
                      this is strictly a funcion of the connector
                      name, efficiency is the only reason to store
                      this.  If no limit, the value is set to 255. */
-    char multi;   /* TRUE if this is a multi-connector */
+    bool multi;   /* TRUE if this is a multi-connector */
 #ifdef USE_FAT_LINKAGES
     Priority priority;/* one of the three priorities above */
     short label;
@@ -214,29 +207,22 @@ struct Match_node_struct
 typedef struct X_node_struct X_node;
 struct X_node_struct
 {
-    const char * string;  /* the word itself */
-    Exp * exp;
-    X_node *next;
+	const char * string;  /* the word itself */
+	Exp * exp;
+	X_node *next;
 };
 
+/* Word, as represented shortly after tokenization, but before parsing. */
 struct Word_struct
 {
-    const char *unsplit_word;
-    const char **alternatives;
-    X_node * x;      /* sentence starts out with these */
-    Disjunct * d;    /* eventually these get generated */
-    Boolean firstupper;
+	const char *unsplit_word;
+	const char **alternatives;
+	X_node * x;          /* Sentence starts out with these, */
+	Disjunct * d;        /* eventually these get generated. */
+	Boolean firstupper;  /* TRUE if capitalized, and is first word of sentence */
 };
 
 
-/* The structure below stores a list of dictionary word files. */
-struct Word_file_struct
-{
-    char file[MAX_PATH_NAME+1];   /* the file name */
-    int changed;             /* TRUE if this file has been changed */
-    Word_file * next;
-};
-
 /* The regexs are stored as a linked list of the following nodes. */
 struct Regex_node_s
 {
@@ -293,7 +279,6 @@ struct Linkage_info_struct
     short link_cost;
     double disjunct_cost;
     double corpus_cost;
-    int island[MAX_SENTENCE];
     size_t nwords;
 #ifdef USE_FAT_LINKAGES
     Boolean canonical;
@@ -312,9 +297,9 @@ struct Linkage_info_struct
 
 struct List_o_links_struct
 {
-    int link;       /* the link number */
-    short word;       /* the word at the other end of this link */
-    short dir;        /* 0: undirected, 1: away from me, -1: toward me */
+    size_t link;     /* the link number */
+    size_t word;     /* the word at the other end of this link */
+    signed char dir; /* 0: undirected, 1: away from me, -1: toward me */
     List_o_links * next;
 };
 
@@ -430,11 +415,11 @@ struct pp_knowledge_s
     pp_rule *contains_one_rules, *contains_none_rules;
     pp_rule *bounded_rules;
 
-    int n_connected_rules, n_form_a_cycle_rules;
-    int n_contains_one_rules, n_contains_none_rules;
-    int n_bounded_rules;
+    size_t n_connected_rules, n_form_a_cycle_rules;
+    size_t n_contains_one_rules, n_contains_none_rules;
+    size_t n_bounded_rules;
 
-    int nStartingLinks;
+    size_t nStartingLinks;
     pp_linkset *set_of_links_starting_bounded_domain;
     StartingLinkAndDomain *starting_link_lookup_table;
     String_set *string_set;
