@@ -3,8 +3,7 @@
 /* All rights reserved                                                     */
 /*                                                                         */
 /* Use of the link grammar parsing system is subject to the terms of the   */
-/* license set forth in the LICENSE file included with this software,      */
-/* and also available at http://www.link.cs.cmu.edu/link/license.html      */
+/* license set forth in the LICENSE file included with this software.      */
 /* This license allows free redistribution and use in source and binary    */
 /* forms, with or without modification, subject to certain conditions.     */
 /*                                                                         */
@@ -13,7 +12,7 @@
 /**
  * Arghhhh. This hacks around mutiple stupidities in readline/editline.
  * 1) most versions of editline don't have wide-char support.
- * 2) All versions of editline don't have UTF8 support.
+ * 2) No versions of editline have UTF8 support.
  * So basically readline() is just plain broken.
  * So hack one up, using the wide-char interfaces.  This is a hack. Argh. 
  *
@@ -92,7 +91,7 @@ char *lg_readline(const char *mb_prompt)
 	wc_line = el_wgets(el, &numc);
 
 	/* Received end-of-file */
-	if (0 == numc)
+	if (numc <= 0)
 	{
 		el_end(el);
 		history_wend(hist);
